aboutsummaryrefslogtreecommitdiff
path: root/apps/systemlib/param/param.h
diff options
context:
space:
mode:
authorpx4dev <px4@purgatory.org>2012-10-09 22:45:36 -0700
committerpx4dev <px4@purgatory.org>2012-10-09 22:45:36 -0700
commit1e59a592a6a41a65e9e69814ae3d8cb62a061367 (patch)
tree5d17bc01ecdd597b7d6c86c18e2ca827050abb51 /apps/systemlib/param/param.h
parentbd3f3b10317f58d20f635f4a3e6aee8fca8d9d2b (diff)
downloadpx4-firmware-1e59a592a6a41a65e9e69814ae3d8cb62a061367.tar.gz
px4-firmware-1e59a592a6a41a65e9e69814ae3d8cb62a061367.tar.bz2
px4-firmware-1e59a592a6a41a65e9e69814ae3d8cb62a061367.zip
Split the parameter load/save commands out of the 'eeprom' command, since that's not really the obvious place for them. Add parameter printing functionality (though, it's a mess due to %f being busted)
Update the script examples to use the new command.
Diffstat (limited to 'apps/systemlib/param/param.h')
-rw-r--r--apps/systemlib/param/param.h17
1 files changed, 16 insertions, 1 deletions
diff --git a/apps/systemlib/param/param.h b/apps/systemlib/param/param.h
index ffce07a4e..41e268db0 100644
--- a/apps/systemlib/param/param.h
+++ b/apps/systemlib/param/param.h
@@ -122,6 +122,20 @@ __EXPORT int param_get_index(param_t param);
__EXPORT const char *param_name(param_t param);
/**
+ * Test whether a parameter's value has changed from the default.
+ *
+ * @return If true, the parameter's value has not been changed from the default.
+ */
+__EXPORT bool param_value_is_default(param_t param);
+
+/**
+ * Test whether a parameter's value has been changed but not saved.
+ *
+ * @return If true, the parameter's value has not been saved.
+ */
+__EXPORT bool param_value_unsaved(param_t param);
+
+/**
* Obtain the type of a parameter.
*
* @param param A handle returned by param_find or passed by param_foreach.
@@ -160,7 +174,8 @@ __EXPORT int param_set(param_t param, const void *val);
/**
* Reset a parameter to its default value.
*
* This function frees any storage used by struct parameters, but scalar parameters
*
* @param param A handle returned by param_find or passed by param_foreach.
*/
@@ -160,7 +174,8 @@ __EXPORT int param_set(param_t param, const void *val);
* Reset a parameter to its default value.
*
- * This function frees any storage used by struct parameters, but scalar parameters
+ * This function frees any storage used by struct parameters, and returns the parameter
+ * to its default value.
*
* @param param A handle returned by param_find or passed by param_foreach.